import Qt 4.7
import "../fonts" as Fonts

Rectangle
{
    id: checkbox

    property variant fontStyles: Fonts.Common{}

    property alias text: buttonText.text
    property alias textfont: buttonText.font
    property alias wrapMode: buttonText.wrapMode
    property alias elide: buttonText.elide
    property variant textcolor: "Black"
    property variant textcolorDisabled: "Gray"

    property int horizontalMargin: 2
    property int verticalMargin: 1
    property real textVerticalMargin: 0

    property int maxWidth: parent.width
    property int maxHeight: 2000
    property bool checked: false
    property string uncheckedImage: "../images/widgets/checkbox.png"
    property string checkedImage: "../images/widgets/checkbox_selected.png"
    property string uncheckedDisabledImage: "../images/widgets/checkbox_disabled.png"
    property string checkedDisabledImage: "../images/widgets/checkbox_selected_disabled.png"

    // private
    property real baseWidth: checkImage.width + 3 * horizontalMargin
    property real textWidth: buttonTextWithoutElide.paintedWidth

    function getImage()
    {
        if(enabled)
            return checked ? checkedImage : uncheckedImage;
        else
            return checked ? checkedDisabledImage : uncheckedDisabledImage;
    }

    width: Math.min(maxWidth, baseWidth + textWidth)
    height: Math.min(widgetArea.height, maxHeight)
    color:"transparent";

    clip:	true

    onFocusChanged:
    {
        shade.visible = focus;
    }

    Keys.onPressed:
    {
        if (Qt.Key_Space == event.key)
        {
            checked = !checked;
        }
    }

    Item
    {
        id: widgetArea
        height: childrenRect.height
        width: parent.width
        Item
        {
            id: topMargin;
            height: checkbox.verticalMargin
            width: parent.width
        }
        Item
        {
            id: visualElements
            anchors.top: topMargin.bottom
            height: Math.max(checkImage.height, buttonText.height)
            width: parent.width

            Image
            {
                id: checkImage
                anchors.left: parent.left
                anchors.leftMargin:	1
                source: checkbox.getImage();
				anchors.top: parent.top
            }
            Text
            {
                id: buttonText
                font: checkbox.fontStyles.standardCheckboxFont
                elide: (!wrapMode || (wrapMode == Text.NoWrap)) ? Text.ElideRight : Text.ElideNone
                verticalAlignment: Text.AlignVCenter
                color: checkbox.enabled ? textcolor : textcolorDisabled
                anchors.left: checkImage.right
                anchors.leftMargin: checkbox.horizontalMargin
                anchors.right: parent.right
                anchors.rightMargin: checkbox.horizontalMargin
				anchors.top: parent.top
				anchors.topMargin: checkbox.textVerticalMargin
            }
            Text
            {
                id: buttonTextWithoutElide
                x: buttonText.x
                y: buttonText.y
                visible: false
                font: buttonText.font
                text: buttonText.text
            }
        }
    }

    MouseArea
    {
        id: mouseArea
        anchors.fill: parent
        hoverEnabled: true
        onClicked:
        {
            checkbox.checked = !checkbox.checked;
        }

        Clickable {}
    }
}
