import Qt 4.7

Item
{
    id: innersView
    objectName: "innersView"
    property bool animationRunning: opacityAnimation.running || animation.running

    function show(panelName)
    {
        displayArea.show(panelName)
    }
    function isShowed(panelName)
    {
        return displayArea.isShowed(panelName)
    }
    function getCurrent()
    {
        return displayArea.getCurrent()
    }
    function get(panelName)
    {
        return displayArea.get(panelName)
    }
    function hide(panelName)
    {
        displayArea.hide(panelName)
    }
    function back()
    {
        displayArea.back()
    }
    function home()
    {
        displayArea.home()
    }
    function setVisible(visible)
    {
        opacity = visible ? 1 : 0
    }
    function getHelpId()
    {
        if (getCurrent().item.helpId != undefined)
    {
            return getCurrent().item.helpId;
    }
        else
        {
            console.log("InnersView::getHelpId: helpId property is not defined for this panel");
            return 0;
        }
    }

    anchors.fill: parent
    opacity: 0
    Behavior on opacity
    {
        SmoothedAnimation
        {
            id: opacityAnimation
            velocity: 4
        }
    }
    onOpacityChanged:
    {
        if (opacity == 0)
            displayArea.reset()
    }
    MouseEventsEater { enabled: opacity > 0 }

    Item
    {
        id: displayArea
        objectName: "displayArea"
        anchors.top: parent.top
        anchors.topMargin: 85 /* from guidelines */
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 35 /* footer */
        width: parent.width - 30
        clip: true
        enabled: !innersView.animationRunning
        anchors.horizontalCenter: parent.horizontalCenter
        Rectangle
        {
            radius: 10
            anchors.fill: displayArea
            color: "white"
        }
        BorderImage
        {
            border.left: 15
            border.right: 15
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            source: "image://preload/common/images/inner/toolbar_white.png"
        }

        InnerPanel { id: panelProblemList; file: "../problem_list/ProblemList.qml" }
        InnerPanel { id: panelScan; file: "../scan/Scan.qml" }
        InnerPanel { id: panelUpdater; file: "../updater/Updater.qml" }
        InnerPanel { id: panelOnline; file: "../ksn/OnlineServices.qml" }
        InnerPanel { id: panelNewsList; file: "../news/NewsList.qml" }
        InnerPanel { id: panelNewsItem; file: "../news/NewsItem.qml" }
        InnerPanel { id: panelSearch; file: "./Search.qml" }
        InnerPanel { id: panelTools; file: "../main_window/AdvancedTools.qml" }
        InnerPanel { id: panelUpgrade; file: "../migration/Upgrade.qml" }
        InnerPanel { id: panelParentalControl; file: "../parental_control/ParentalControl.qml" }
        InnerPanel { id: panelSafeProgramsStartup; file: "../sandbox/SafeProgramsStartup.qml" }
        InnerPanel { id: panelSafeWebSitesBrowsing; file: "../sandbox/SafeWebSitesBrowsing.qml" }
        InnerPanel { id: panelLicenseManager; file: "../license/LicenseManager.qml" }
        InnerPanel { id: panelAboutCloudProtection; file: "../ksn/AboutCloudProtection.qml" }
        // all elements on left side organized in double linked list
        property variant first // first element on left side
        property variant last // last element on left side
        property variant current // visible element
        Connections
        {
            ignoreUnknownSignals: true
            target: displayArea.current ? displayArea.current : ambrazura
            onBack: displayArea.back()
            onHome: displayArea.home()
            onActivate: displayArea.show(panelName)
        }

        function canHome(panel)
        {
            return panel != first && (first != undefined || panel != current)
        }

        function reset()
        {
            if (current)
            {
                current.hide()
                current = undefined
            }
            while (first)
            {
                var temp = first.next
                first.prev = undefined
                first.next = undefined
                first = temp
            }
            last = undefined
        }
        function moveToRight(panel)
        {
            if (panel.prev || panel.next || first == panel)
            {
                if (panel.prev)
                    panel.prev.next = panel.next
                else
                    first = panel.next
                if (panel.next)
                    panel.next.prev = panel.prev
                else
                    last = panel.prev
                panel.next = panel.prev = undefined
            }
        }
        SequentialAnimation
        {
            id: animation
            property bool leftIsOld
            property alias oldPanel: oldPanelAnimation.target
            property alias newPanel: newPanelAnimation.target
            property int velocity: 1200
            ParallelAnimation
            {
                SmoothedAnimation
                {
                    id: oldPanelAnimation
                    property: "x";
                    to: (animation.leftIsOld ? -1 : 1) * (target ? target.width : 0)
                    //duration: target ? target.width / animation.velocity : 0
                    velocity: animation.velocity
                }
                SmoothedAnimation
                {
                    id: newPanelAnimation
                    property: "x";
                    to: 0;
                    //duration: target ? target.width / animation.velocity : 0
                    velocity: animation.velocity
                }
            }
            ScriptAction
            {
                script:
                {
                    animation.oldPanel.hide()
                }
            }
        }
        function commonAnimate(leftPanel, rightPanel, leftIsOld)
        {
            var oldPanel = leftIsOld ? leftPanel : rightPanel
            var newPanel = leftIsOld ? rightPanel : leftPanel
            newPanel.x = leftIsOld ? newPanel.width : -newPanel.width
            newPanel.show()
            animation.oldPanel = oldPanel
            animation.newPanel = newPanel
            animation.leftIsOld = leftIsOld
            animation.running = true
        }
        function animateShow(leftPanel, rightPanel)
        {
            commonAnimate(leftPanel, rightPanel, true);
        }
        function animateHide(leftPanel, rightPanel)
        {
            commonAnimate(leftPanel, rightPanel, false);
        }
        function show(panelName)
        {
            var panel = eval(panelName);
            if (panel == current)
                return;
            moveToRight(panel)
            innersView.setVisible(true)
            if (!current)
            {
                panel.x = 0;
                panel.show();
                current = panel;
                return
            }
            if (last)
            {
                last.next = current
                current.prev = last
                last = current
            }
            else
            {
                first = current
                last = current
            }
            animateShow(current, panel)
            current = panel
        }
        function isShowed(panelName)
        {
            var panel = eval(panelName)
            return panel && (current == panel || panel.prev || panel.next || first == panel);
        }
        function getCurrent()
        {
            return current;
        }
        function get(panelName)
        {
            return eval(panelName);
        }
        function hide(panelName)
        {
            if (!current)
                return
            var panel = eval(panelName)
            if (panel == current)
                back()
            else
                moveToRight(panel)
        }
        function back()
        {
            if (!current)
                return
            if (last)
            {
                animateHide(last, current)
                current = last
                last = last.prev
                if (last)
                    last.next = undefined
                else
                    first = undefined
                current.prev = undefined
                current.next = undefined
            }
            else
            {
                home()
            }
        }
        function home()
        {
            innersView.setVisible(false);
        }
    }

    BorderImage
    {
        id: ambrazura_bottom
        anchors.bottom: parent.bottom
        anchors.left  : parent.left
        anchors.right : parent.right
        border { left: 30; right: 30 }
        source: "image://preload/common/images/inner/bg_bottom_gray.png"
    }

    BorderImage
    {
        id: ambrazura
        anchors.fill: parent
        anchors.bottomMargin : ambrazura_bottom.height
        border { left: 30; right: 30; top: 150; bottom: 35 }
        source: "image://preload/common/images/inner/innercontent.png"
    }

    MainFooter
    {
		objectName: "mainFooter"
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: displayArea.bottom
        anchors.bottom: parent.bottom
        textColor: "#dddddd"
		textcolorHovered: "#ffffff"
		textcolorPressed: "#dddddd"
    }
}
