import Qt 4.7
import "../common/widgets" as Widgets
import "../dashboard" as Dashboard
import "../common/ViewManager.js" as ViewManagerForBackView
import "../common/EnumHelper.js" as EnumHelper
import "../common/border" as Border
import "../common/fonts" as Fonts

Widgets.FlipableY
{
    id: flipPanel
    objectName: "TopFlipPanel"
    property int panelWidth: 729
    property int panelHeight: 547
    width: childrenRect.width
    height: childrenRect.height

    front: mainViewBordered
    back: backViewBordered

    function showPage(page)
{
        var separatorPosition = page.search(":");
        if (separatorPosition == -1) separatorPosition = page.length;
        if (!separatorPosition)
            return;
        var currentPage = page.slice(0, separatorPosition);
        var page = page.slice(separatorPosition + 1);

        var mapOfWindowParams = {
            "WelcomePage":			{path: "../startup/WelcomePage.qml", isOnBackSide: true},
            "ActivationWizard":		{path: "../activation/ActivationWizard.qml", isOnBackSide: true},
            "MigrationWizard":		{path: "../migration/MigrationWizard.qml", isOnBackSide: true},
            "EndOfLicense":			{path: "../license/EndOfLicense.qml", isOnBackSide: true},
            "Updater":				{panel: "panelUpdater", isOnBackSide: false},
            "ProblemList":			{panel: "panelProblemList", isOnBackSide: false},
            "Scan":					{panel: "panelScan", isOnBackSide: false},
            "Online":				{panel: "panelOnline", isOnBackSide: false},
            "NewsList":				{panel: "panelNewsList", isOnBackSide: false},
            "NewsItem":				{panel: "panelNewsItem", isOnBackSide: false},
            "Search":				{panel: "panelSearch", isOnBackSide: false},
            "Tools":				{panel: "panelTools", isOnBackSide: false},
            "Upgrade":				{panel: "panelUpgrade", isOnBackSide: false},
            "ParentalControl":		{panel: "panelParentalControl", isOnBackSide: false},
            "SafeProgramsStartup":	{panel: "panelSafeProgramsStartup", isOnBackSide: false},
            "SafeWebSitesBrowsing":	{panel: "panelSafeWebSitesBrowsing", isOnBackSide: false},
            "LicenseManager":		{panel: "panelLicenseManager", isOnBackSide: false}
        };
        var params = mapOfWindowParams[currentPage];
        if (!params || (!params.path && !params.panel))
        {
            console.log("windowPage for '" + currentPage + "' has not been found");
            return;
        }
        var newPage = undefined;
        if (params.isOnBackSide)
        {
            if ("WelcomePage" != currentPage || !flipPanel.isFlipped())
                newPage = backView.showPage(params);
        }
        else
        {
            mainView.showPage(params);
            if (flipPanel.isFlipped())
                backView.closePage();
        }
        if (page && newPage && (typeof newPage.showPage == "function"))
            newPage.showPage(page);
    }

    Border.BorderedContent
    {
        id: backViewBordered
        objectName: "backViewBordered"
        content: backView
    }
    CustomLoader
    {
        id: backView
        objectName: "backView"
        parent: backViewBordered
        width: panelWidth
        height: panelHeight

        function showPage(params)
        {
            if (file == params.path)
                return;
            viewManager().goTop();
            file = params.path;
            unloadTimer.running = false;
            viewManager().goTop();
            viewManager().show(eval(backView));
            item.duration = 0;
            return backView;
        }
        function closePage()
        {
            backView.file = "";
            flipPanel.flipBack();
            unloadTimer.interval = 1000;
            unloadTimer.running = true;
        }
        Connections
        {
            target: backView.item
                        onClose: Window.Close()
                        onCancel: backView.closePage()
        }
        function viewManager() {return ViewManagerForBackView;}

        onStatusChanged:
        {
            switch (status)
            {
                case Loader.Null:
                {
                    if (!file)
                        flipPanel.flipBack();
                    break;
                }
                case Loader.Error:
                {
                    source = "";
                    closePage();
                    break;
                }
            }
        }
        onLoaded:
        {
            flipPanel.flip();
        }

        Timer
        {
            id: unloadTimer;
            running: false;
            onTriggered: backView.viewManager().doBack();
        }
    }

    Border.BorderedContent {
        id: mainViewBordered
        content: mainView
    }
    Item
    {
        id: mainView
        parent: mainViewBordered
        width: panelWidth
        height: panelHeight
        objectName: "MainView"
        property int helpId: 39838

        function showPage(params)
        {
                if (params.panel)
                    innersView.show(params.panel);
        }

        function getHelpId()
        {
            return helpId;
        }

        Item
        {
            id: backLayer
            objectName: "BackLayer"
            anchors.fill: parent
            enabled: innersView.opacity == 0

            BorderImage
            {
                id: mainBackground
                anchors.fill: parent
                anchors.bottomMargin: 30
                border { left: 20; top: 20; right: 20; bottom: 20 }
                source: "image://preload/common/images/main_window/bg_small.png"
            }

            BorderImage
            {
                id: greenBottom
                anchors.bottom: parent.bottom
                anchors.left:   parent.left
                anchors.right:  parent.right
                border { left: 30; right: 30 }
                source: "image://preload/common/images/main_window/green_bottom.png"
                visible: innersView.opacity < 1
            }

            FeatureBoxBackground
            {
                id: featureBoxBackround1
                anchors.fill: featureBox
                visible: featureBox.currentView == featureBox.smallView && !featureBox.animationRunning
            }

            Widgets.Button
            {

            }

            Texture
            {
                anchors.fill: parent
            }

            Dashboard.Dashboard
            {
                id: dashboard
                objectName: "dashboard"
                anchors.top: parent.top
                anchors.topMargin: 85 /* from guideline */
                anchors.left   : parent.left
                anchors.leftMargin: 15
                anchors.right  : parent.right
                anchors.rightMargin: 200
                anchors.bottom : parent.bottom
                anchors.bottomMargin: featureBox.smallView.height + mainFooter.height + 10;

                function onNavigateTo()
                {
                    Statistics.onNavigateTo(objectName);
                }

                Component.onCompleted:
                {
                    onNavigateTo()
                }
                onProblemListButtonPressed: innersView.show("panelProblemList")
            }

            FeatureBoxBackground
            {
                id: featureBoxBackround2
                anchors.fill: featureBox
                visible: !featureBoxBackround1.visible
            }

            Image
            {
				x: 580
				y: 155
				AnimatedImage
				{
					source: "../common/images/main_window/bomb.gif"
				}
			}

            Item
            {

            }

            FeatureBox
            {
                id: featureBox
                objectName: "featureBox"
                anchors.bottom: greenBottom.top
                anchors.left:   parent.left
                anchors.right:  parent.right
                onActivate:     innersView.show(panelName)
            }

            Widgets.BaseButton
            {
                id: tongueDown
                anchors.fill: tongueDownGraphics
                objectName: "tongueDown"
                property int tabOrder: 301
                enabled: !featureBox.animationRunning
                onClicked: featureBox.down()
            }
			
            Image
            {
                id: footerSeparator
                source: "image://preload/common/images/main_window/featurebox/separator.png";
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 35
                width: parent.width
            }

	        function getHelpId()
	        {
	            return mainView.getHelpId();
	        }

            MainFooter
            {
                id: mainFooter
                objectName: "mainFooter"
                anchors.left:   parent.left
                anchors.right:  parent.right
                anchors.bottom: parent.bottom
                anchors.top: footerSeparator.bottom
                textColor: "#dddddd"
				textcolorHovered: "#ffffff"
				textcolorPressed: "#dddddd"
            }
        }

        InnersView
        {
            id: innersView
            objectName: "innersView"
            enabled: opacity == 1
            onOpacityChanged:
            {
                if (opacity == 0)
                    dashboard.onNavigateTo()
            }
        }

        Item
        {
            id: topLayer
            objectName: "TopLayer"
            enabled: !innersView.animationRunning
            anchors.fill: parent

            Widgets.Button
            {
                x: 15 /* dashboard margin */ + 25 /* from guideline */
                y: 30 /* from guideline */
                iconImage: "image://preload/common/images/main_window/logo.png"
                property int tabOrder: 501

                onClicked: MainWindow.startPage.ShowProductInfo();
                objectName: "productInfo"
            }

            Widgets.Button
            {
                id: onlineButton
                objectName: "OnlineButton"

            }

            Row
            {
                id: windowButtons
                objectName: "WindowButtons"
                anchors.right: parent.right
                anchors.rightMargin: 15
                anchors.top: parent.top
                spacing: 0
                Widgets.Button
                {
                    property string prefix: "image://preload/common/images/window/windowbutton_search_" + (innersView.get("panelSearch") == innersView.getCurrent() ? "selected_" : "");
                    objectName: "Search"
                    iconImage: prefix + "normal.png"
                    iconHoverImage: prefix + "hover.png"
                    iconPressedImage: prefix + "pressed.png"
                    onClicked:
                    {
                        var showed = innersView.getCurrent() == innersView.get("panelSearch")
                        if (showed)
                            innersView.back()
                        else
                            innersView.show("panelSearch")
                        }
                    }
                Widgets.Button
                {
                    objectName: "Minimize"
                    iconImage: "image://preload/common/images/window/windowbutton_minimize2_normal.png"
                    iconHoverImage: "../images/window/windowbutton_minimize2_hover.png"
                    iconPressedImage: "../images/window/windowbutton_minimize2_pressed.png"
                    onClicked: Window.Minimize()
                }
                Widgets.Button
                {
                    objectName: "Close"
                    iconImage: "image://preload/common/images/window/windowbutton_close_normal.png"
                    iconHoverImage: "../images/window/windowbutton_close_hover.png"
                    iconPressedImage: "../images/window/windowbutton_close_pressed.png"
                    onClicked: Window.Close()
                }
            }

            Row
            {
                id: topButtons
                visible: moveSearch.state == "Hide"
                anchors.right: parent.right
                anchors.rightMargin: 30 /* right margin */
                anchors.top: parent.top
                anchors.topMargin: 40
                objectName: "topButtons"

                spacing: 15
                TopBarButton
                {
                    iconImage: "image://preload/common/images/main_window/topbar/news_normal.png"
                    iconHoverImage: "../images/main_window/topbar/news_hover.png"
                    iconPressedImage: "../images/main_window/topbar/news_pressed.png"
                    onClicked: { innersView.show("panelNewsList"); }
                    visible: { MainWindow.startPage.AllNewsCount > 0; }
                    property int tabOrder: 102
                }
                TopBarButton
                {
					iconImage : "../images/main_window/online.png"
					iconHoverImage : "../images/main_window/online_hover.png"
					iconPressedImage : "../images/main_window/online_pressed.png"
                    onClicked: { innersView.show("panelOnline"); }
                    property int tabOrder: 103
				}
                TopBarButton
                {
                    iconImage: "image://preload/common/images/main_window/topbar/reports_normal.png"
                    iconHoverImage: "../images/main_window/topbar/reports_hover.png"
                    iconPressedImage: "../images/main_window/topbar/reports_pressed.png"
                    onClicked: { MainWindow.startPage.ShowReports(); }
                    property int tabOrder: 104
                }
                TopBarButton
                {
                    iconImage: "image://preload/common/images/main_window/topbar/settings_normal.png"
                    iconHoverImage: "../images/main_window/topbar/settings_hover.png"
                    iconPressedImage: "../images/main_window/topbar/settings_pressed.png"
                    onClicked: { MainWindow.startPage.ShowSettings(); }
                    property int tabOrder: 105
                }
            }

            Item
            {
                objectName: "Search"
                anchors.right: parent.right
                anchors.rightMargin: 15 /* right margin */
                anchors.bottom: parent.top 
                anchors.bottomMargin: parent.top -75
                width: moveSearch.width
                height: moveSearch.height
                clip: true

                SlidePanel
                {
                    id: moveSearch
                    objectName: "SlidePanel"
                    anchors.right: parent.right

                    onHide:-parent.height
                    onShow:0

                    width: search.width;
                    height: search.height;
                    color: "transparent"

                    property alias text: search.text

                    onStateChanged:
                    {
                        if (state == "Show")
                        {
							searchTimer.interval = 700;
							searchTimer.running = true;
                        }
                        else
                        {
							 searchTimer.running = false;
                        }
                    }

                    SearchBox
                    {
                        id: search
                        onTextChanged:
                        {
                            var panel = innersView.get("panelSearch").item;
                            if (panel)
                                panel.updateSearchList(moveSearch.text);
                            search.sfocus = true
                        }
                        onIsActiveFocusChanged: searchTimer.running = false;
                        Timer
						{
							id: searchTimer;
							running: false;
							onTriggered: search.setActiveFocus();
						}
                    }
                }
            }

        }
    }
    Widgets.DPIScaler
    {
        id: dpiScaler
        changeSize: true
        widthProperty: "panelWidth"
        heightProperty: "panelHeight"
    }
    Keys.onPressed: { if (event.key == Qt.Key_F1) Help.Show(mainView.getHelpId()); }
}
