import Qt 4.7
import QtWebKit 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../main_window" as MainFrame

MainFrame.InnerContent
{
	caption: MainWindow.newsList.CurrentNewsTitle
	property int helpId: 44290
	objectName: "newsItem"

	Component.onCompleted:
	{
		MainWindow.newsList.MarkCurrentNewsAsRead(); 
	}

    captionArea: Component
    {
        Item
        {
            property variant context: MainWindow.newsList
            objectName: "captionArea"

            Widgets.CaptionButton
            {
                id: nextButton
                objectName: "nextButton"
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right
                anchors.rightMargin: 8
        minWidth: 0
		iconImage: "../images/news/news_arrow_right.png"
                enabled: context.CurrentNewsIndex + 1 < context.NewsCount;
                onClicked: { 
                    context.CurrentNewsIndex++;
                    context.MarkCurrentNewsAsRead();
                }
            }
            Widgets.CaptionButton
            {
                id: prevButton
                objectName: "prevButton"
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: nextButton.left
                anchors.rightMargin: 4
        minWidth: 0
		iconImage: "../images/news/news_arrow_left.png"
                enabled: context.CurrentNewsIndex > 0;
                onClicked: {
                    context.CurrentNewsIndex--;
                    context.MarkCurrentNewsAsRead();
                }
            }
        }
    }

    viewArea: Component
    {
        Item
        {
            property variant commonFontStyles: Fonts.Common{}
            property variant context: MainWindow.newsList
            Flickable
            {
                id: scrollView
                width: parent.width
                height: parent.height
                contentHeight: column.height
                clip: true

                Column
                {
                    id: column
                    y: 15
                    width: parent.width;

                    Widgets.StandardCaptionText
                    {
                        id: title
                        x:25
                        width: parent.width - 180
                        text: context.CurrentNews.title
                        wrapMode: Text.WordWrap
                    }
                    Text
                    {
                        id: dateTime
                        anchors.right: parent.right; anchors.rightMargin: 30
                        anchors.top: title.top
                        font: commonFontStyles.standardCommonTextFont
                        color: "#7f7f7f"
                        text: context.CurrentNews.dateTime
                    }
                    Item
                    {
                        anchors.top: title.bottom; anchors.topMargin: 10
                        anchors.left: parent.left; anchors.leftMargin: 30
                        anchors.right: parent.right; anchors.rightMargin: 30
                    }
		    WebView
		    {
			id: content
		
                        anchors.left: title.left
                        anchors.right: parent.right; anchors.rightMargin: 30
                        anchors.top: title.bottom; anchors.topMargin: 20
                        height: paintedHeight;
		
			settings.autoLoadImages: true
			settings.javascriptEnabled: true
			settings.linksIncludedInFocusChain: true
		
			html: "<script>window.addEventListener('DOMContentLoaded', function() { var anchors = document.getElementsByTagName('a'); for(var i = 0; i < anchors.length; i++) { anchors[i].addEventListener('click', function(event){window.linkHandler.onClick(this.href);});} });</script>" + context.CurrentNews.content

			javaScriptWindowObjects: QtObject {
         			WebView.windowObjectName: "linkHandler"

         			function onClick(event) 
				{
					console.log(event);
					context.OpenLink(event);
         			}
     			}

		    }
                }
            }
            Widgets.FlickableScrollBar
            {
                id:scrollbar
                target:scrollView
                anchors.top:scrollView.top;
                anchors.topMargin: 5
                anchors.right:parent.right;
                anchors.rightMargin: 5
                anchors.bottom: scrollView.bottom;
                anchors.bottomMargin: 5
            }
        }
    }
}
