import Qt 4.7
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper
import "../main_window" as MainFrame

MainFrame.InnerContent
{
    id: newsList

	caption: MainWindow.newsList.Localize("NewsList_Title")
	property int helpId: 44289
	objectName: "newsList"

	Component.onCompleted:
	{
		MainWindow.newsList.SetNewsListVisited(); 
	}

    captionArea: Component
    {
        Item
        {
            property variant context: MainWindow.newsList
            objectName: "captionArea"

            Widgets.CaptionButton
            {
                id: settingsButton
                objectName: "settingsButton"
                minWidth: 0
                iconImage: "../images/news/ico_bell.png";
                onClicked: { 
                    MainWindow.InvokeSkinAction("dialog(\"NewsSettings\")")
                }
            }
        }
    }

    viewArea: Component
    {
        Item
        {
            property variant context: MainWindow.newsList
            property variant commonFontStyles: Fonts.Common{}
            objectName: "listFrameOuter"

            Item
            {
                anchors.fill: parent
                clip: true
                objectName: "listFrameInner"

                ListView
                {
                    id: newsListView
                    objectName: "newsListView"
                    anchors.fill: parent
                    model : context.News
                    clip: true
                    delegate :
                    Item
                    {
                        id: row
                        objectName: "row"
                        width: parent.width
                        height: separator.y + separator.height

                        Text
                        {
                            id: title
                            x: 54
                            anchors.top: parent.top
                            anchors.topMargin: 15
                            font: commonFontStyles.standardSmallCaptionFont
                            text: model.modelData.title
                            width: parent.width - 180
                            wrapMode: Text.WordWrap
                        }
                        Image
                        {
                            id: readIcon
                            x: 20
                            anchors.top:title.top
                            anchors.topMargin: 2
                            source: EnumHelper.convert(model.modelData, "read",
                                        {"Read":"../common/images/news/ico_message_empty_16.png",
                                         "Unread":"../common/images/news/ico_message_new_16.png"});
                        }
                        Image
                        {
                            id:statusIcon

                            anchors.right: dateTime.right
                            anchors.rightMargin: -5 // image margin
                            anchors.top: dateTime.bottom
                            anchors.topMargin: 2;
                            source: EnumHelper.convert(model.modelData, "importance",
                                        {"Alert":"../common/images/news/news_alert.png",
                                         "Warning":"../common/images/news/news_alert.png",
                                         "Information":""});
                            Text {
                                anchors.centerIn: parent
                                anchors.verticalCenterOffset: -2
                                anchors.horizontalCenterOffset: -2
                                color: "white"
                                font: commonFontStyles.standardCommonTextFont
                                text:
                                {
                                    return EnumHelper.convert(model.modelData, "importance",
                                        {"Alert":context.Localize("Alert"),
                                         "Warning":context.Localize("Warning"),
                                         "Information":""});
                                }
                            }
                        }
                        Text
                        {
                            id: dateTime
                            anchors.right: parent.right; anchors.rightMargin: 25
                            anchors.top: title.top
                            font: commonFontStyles.standardCommonTextFont
                            color: "#7f7f7f"
                            text: model.modelData.dateTime
                        }
                        Text
                        {
                            id: description
                            anchors.left: title.left
                            anchors.right: title.right
                            anchors.top: title.bottom; anchors.topMargin: 5
                            height: text == "" ? 0 : paintedHeight
                            wrapMode: Text.WordWrap
                            font: commonFontStyles.standardCommonTextFont
                            text: model.modelData.description
                            clip: true
                        }
                        Widgets.GrayButton
                        {
                            id: readMore
                            objectName: "readMore"
                            anchors.left: title.left
                            anchors.top: description.bottom; anchors.topMargin: 8
                            text: context.Localize("ReadMore")
                            onClicked:
                            {
                                context.CurrentNewsIndex = index;
                                newsList.activate("panelNewsItem");
                            }
                        }
                        Image
                        {
                            id: separator
                            source: "../common/images/inner/list_separator.png"
                            anchors.top: readMore.bottom
                            anchors.topMargin: 17
                            visible: index < row.ListView.view.count - 1
                            width: parent.width
                        }
                    }
                }
                Widgets.FlickableScrollBar
                {
                    id:scrollBar
                    target: newsListView
                    height: parent.height - 10
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.right: parent.right
                    anchors.rightMargin: 5
                }
            }
        }
    }
}
