import Qt 4.7
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper

Image
{
	id: safeDesktopWaiting
	objectName:	"SafeDesktopWaiting"

	property variant fontStyles: Fonts.SandBox{}
	property variant context: Sandbox

	source:		"../common/images/sandbox/light_overlay.png"
	fillMode:	Image.Stretch
	smooth:		true
	
	Component.onCompleted: 
	{
		context.SwitchSafeDesktopAction.Invoke() 
	}	

	function hasWarnings(context, initializationState)
	{
		return EnumHelper.convert(context, initializationState, {
			"InProgress" : false,
			"Completed"  : false,
			"Timeouted"  : true,
			"Failed"     : true});
	}

	function getStateName(context, initializationState)
	{
		return EnumHelper.convert(context, initializationState, {
			"InProgress" : context.Localize("WaitingForSafeDesktop"),
			"Completed"  : context.Localize("WaitingForSafeDesktop"),
			"Timeouted"  : context.Localize("SafeDesktopInitializationError"),
			"Failed"     : context.Localize("SafeDesktopInitializationError")});
	}

	function getStateDescription(context, initializationState)
	{
		return EnumHelper.convert(context, initializationState, {
			"InProgress" : context.Localize("WaitingForSafeDesktop_InProgress"),
			"Completed"  : "",
			"Timeouted"  : context.Localize("SafeDesktopInitializationTimeouted"),
			"Failed"     : context.Localize("SafeDesktopInitializationFailed")});
	}

	function isTimeoutedState()
	{
		return EnumHelper.getKey(context, "InitializationState") == "Timeouted";
	}

	function isFailedState()
	{
		return (isTimeoutedState() || EnumHelper.getKey(context, "InitializationState") == "Failed");
	}

	function isCompletedState()
	{
		return EnumHelper.getKey(context, "InitializationState") == "Completed";
	}

	property bool isInitializationFailed: isFailedState()
	property bool isInitializationTimeouted: isTimeoutedState()

	property variant initializationState: context.InitializationState;
	onInitializationStateChanged:
	{
		console.log("isFailedState()=" + isFailedState())
		buttonsGroup.visible = isFailedState();

		console.log("isTimeoutedState()=" + isFailedState())
		retryButton.visible = isTimeoutedState()

		if (isCompletedState())
			Window.Close();
	}

	Image
	{
		id:				symbolImage
		y:				0.13 * parent.height
		anchors.horizontalCenter:parent.horizontalCenter
		source:			"../common/images/widgets/logo.png"
	}

	Column
	{
		objectName:	"column"
		anchors
		{
			horizontalCenter:parent.horizontalCenter
			verticalCenter: parent.verticalCenter
            verticalCenterOffset: 60
		}

		Item
		{
			width: romashka.width
			height: romashka.height
			anchors.horizontalCenter: parent.horizontalCenter
            Widgets.Loading48
            {
				id: romashka
                visible: !hasWarnings(context, "InitializationState")
			}
			Image
			{
				anchors.centerIn: romashka
				source: "../common/images/ico_warning_48.png"
				visible: !romashka.visible
			}
		}
        Item { width: parent.width; height: 18 }

		Text
		{
			id: waitingText
			anchors.horizontalCenter: parent.horizontalCenter
			font: fontStyles.waitingScreenAction
			text: getStateName(context, "InitializationState")
		}

        Item { width: parent.width; height: 2 }

		Text
		{
			id: descriptionText
			anchors.horizontalCenter: parent.horizontalCenter
			font: fontStyles.waitingScreenDescription
			text: getStateDescription(context, "InitializationState")
			visible: !text.empty
		}

        Item { width: parent.width; height: 16 }

        Item
        {
			id: buttonsGroup
			objectName:	"buttonsGroup"
            width: childrenRect.width
            height: childrenRect.height
            visible: isInitializationFailed
            anchors.horizontalCenter: parent.horizontalCenter
            Widgets.GreenButton
            {
                id: retryButton
                objectName: "RetryButton"
                visible: isInitializationTimeouted
                minWidth: 100
                text: context.Localize("Retry");
                onClicked: context.SwitchSafeDesktopAction.Invoke()
            }
            Widgets.GrayButton
            {
                id: cancelButton
                anchors.left: retryButton.right
                anchors.leftMargin: 8
                objectName: "CancelButton"
                minWidth: 100
                text: context.Localize("Cancel");
                onClicked: Window.Close()
            }
        }
	}
}
