import Qt 4.7
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper
import "../common/Colors.js" as Colors

Item
{
	objectName: "taskList"
    property alias listView: taskListView
    property variant commonFontStyles: Fonts.Common{}
    property real contentHeight: Math.max(Math.min(taskListView.visible ? taskListView.contentHeight : 100, 450), 100)

    Behavior on contentHeight
    {
        id: behavior
        enabled: false
        PropertyAnimation { id: animation; duration: 500; easing.type: Easing.InOutQuad; }
    }

    Timer
    {
        // disable animation for loading items in taskListView at start (component.onCompleted does not work here)
        interval: 500
        running: true
        onTriggered: behavior.enabled = true
    }

    anchors.fill: parent

    ListView
    {
        id:taskListView
        objectName: "taskListView"
        anchors.fill:	parent
        model:			TaskList.TaskList
        delegate:		itemDelegate
        focus:			true
        visible: count > 0
        Widgets.FlickableScrollBar
        {
            target: taskListView
            height: taskListView.height - 10
            anchors
            {
                verticalCenter: taskListView.verticalCenter
                right: taskListView.right
                rightMargin: 5
            }
            visible: taskListView.contentHeight > 450
        }
    }
    Widgets.EmptyListText
    {
        id: noTasksText
        visible: !taskListView.visible
        text: TaskList.Localize("NoTasks");
    }

    function getTaskName(object, componentType)
    {
        return EnumHelper.convert(object, componentType, {
            "Idle":"TaskManager_IdleScan",
            "Full":"TaskManager_FullScan",
            "Vulnerability":"TaskManager_VulnerabilityScan",
            "CriticalArea":"TaskManager_CriticalAreaScan",
            "CustomArea":"TaskManager_CustomScan",
            "ActiveThreatCure":"TaskManager_ActiveThreatCure",
            "QScan":"TaskManager_QScan",
            "Unknown":""});
    }

    Component
    {
        id: itemDelegate

        Item
        {
            id:	itemBounds
            objectName: "itemBounds"
            property QtObject taskModel: model.modelData

            height:	scanFlip.height;
            width:	parent.width

            signal start
            signal pause
            signal stop

            function setFrontPosition()	{scanFlip.state = "";}
            function setBackPosition(){scanFlip.state = "back";}

            property bool isRunning: taskModel.IsRunning && !taskModel.IsStopping
            onIsRunningChanged:
            {
                setFrontPosition()
            }

            Widgets.FlipableY
            {
                id: 	scanFlip
                objectName: "scanFlip"
                width: 	parent.width
                height:	frontView.height

                front: Item
                {
                    id:		frontView
                    objectName: "frontView"
                    width:	parent.width
                    height:	scanTaskBorder.height

                    Rectangle
                    {
                        id:				scanTaskBorder
                        objectName: "scanTaskBorder"
                        width:			parent.width;
                        color:			"transparent"
                        border.color: Colors.grayBorder
                        clip: true

                        height:  dinamicItems.y + dinamicItems.height + 23
                        Item
                        {
                            id:		dinamicItems
                            objectName: "dynamicItems"
                            y: 		22
                            width: 	parent.width - 50
                            anchors.horizontalCenter: parent.horizontalCenter
                            height: vulnerabilitiesList.visible ? (vulnerabilitiesList.y + vulnerabilitiesList.height) : (progress.visible ? (progress.y + progress.height) : (dynamicFields.y + dynamicFields.height))
                            Text
                            {
                                id:				title
                                text: 			taskModel.Localize(getTaskName(taskModel, "Type"));
                                color:			"black";
                                font:			commonFontStyles.standardSmallCaptionFont
                            }
                            Item
                            {
                                id:			progressInfo
                                objectName: "progressInfo"
                                anchors.left: title.right
                                anchors.leftMargin: 10
                                anchors.verticalCenter: title.verticalCenter
                                Text
                                {
                                    anchors.verticalCenter: parent.verticalCenter
                                    id:			progressInfoText
                                    text: 		(taskModel.IsRunning ? taskModel.CompletionPercent : 0) + "%";
                                    color: 		EnumHelper.getKey(taskModel, "Type") == "ActiveThreatCure" ? "Red" : "Gray";
                                    font:		commonFontStyles.standardSmallCaptionFont
                                    visible: 	taskModel.IsRunning
                                }

                                Image
                                {
                                    anchors.verticalCenter: parent.verticalCenter
                                    anchors.verticalCenterOffset: -2
                                    id:					imageDone
                                    anchors.left: 		parent.left;
                                    source: 			"../common/images/key_check.png"
                                    visible: taskModel.IsCompleted;
                                }
                            }

                            Item
                            {
                                id: 				dynamicFields
                                objectName: "dynamicFields"
                                anchors.top:		title.bottom;
                                width:				parent.width
                                height:				descriptionForScan.visible ? descriptionForScan.height : descriptionForFailedScan.height
                                anchors.topMargin:	6

                                function isCurrentObjectVisible()
                                {
									var isActive = taskModel.IsRunning && !taskModel.IsStopping;
									return (isActive || (!isActive && EnumHelper.getKey(taskModel, "Type") == "CustomArea")) && !taskModel.IsFailed;
                                }
                                function getCurrentText()
                                {
                                    if(EnumHelper.getKey(taskModel, "Type") == "CustomArea")
                                    {
                                        if(taskModel.IsRunning)
                                            return "TaskManager_CaptionScan";
                                        else
                                            return taskModel.IsKsnStatisticsAvailable ? "TaskManager_CaptionObject" : "TaskManager_CaptionObjects";

                                    }
                                    if(EnumHelper.getKey(taskModel, "Type") == "Full")
                                        return "TaskManager_CaptionScan";

                                    return "TaskManager_CaptionObject";
                                }
                                function isStatisticsVisible()
                                {
                                    return EnumHelper.getKey(taskModel, "Type") == "CustomArea" && taskModel.IsKsnStatisticsAvailable && !taskModel.IsRunning;
                                }
                                function isRequestedScanObjectsVisible()
                                {
                                    return EnumHelper.getKey(taskModel, "Type") == "CustomArea" && !taskModel.IsRunning;
                                }
                                Column
                                {
                                    id: 				descriptionForScan
                                    width:				parent.width
                                    spacing:			3
                                    visible: !taskModel.IsFailed;
                                    Widgets.StaticLabel
                                    {
                                        caption:	taskModel.Localize(dynamicFields.getCurrentText())
                                        value:		dynamicFields.isRequestedScanObjectsVisible() ? taskModel.RequestedScanObjects : taskModel.CurrentObjectName;
                                        captionFont:commonFontStyles.standardCommonTextFont
                                        valueFont:	commonFontStyles.standardCommonTextFont
                                        visible:	dynamicFields.isCurrentObjectVisible();

                                        anchors.left: parent.left
                                        anchors.right: parent.right
                                        valueAnchors.rightMargin: 22

                                        isWrapMode: false
                                        valueElide:	Text.ElideMiddle
                                    }
                            Row
                            {
                                id:			timeLeft
                                spacing: 4
                                visible:	taskModel.IsRunning
                                Text
                                {
                                    text: taskModel.Localize("TaskManager_CaptionRemain")
                                    font: commonFontStyles.standardCommonTextFont
                                }
                                Widgets.Hyperlink
                                {
                                    text: taskModel.RemainingTime
                                    onClicked: taskModel.ShowScanObjectReport();
                                }
                            }
                            Row
                            {
                                visible:	!timeLeft.visible
                                spacing: 4
                                Text
                                {
                                    text:
                                    {
										return taskModel.IsCompleted ?
										taskModel.Localize("TaskManager_CaptionComplete") :
										taskModel.Localize("TaskManager_CaptionStopped");
									}
                                    font: commonFontStyles.standardCommonTextFont
                                }
                                Widgets.Hyperlink
                                {
                                    text: taskModel.DurationSinceLastStop
                                    onClicked: taskModel.ShowScanObjectReport();
                                }
                            }
                                    Widgets.StaticLabel
                                    {
                                        caption:	taskModel.Localize("TaskManager_CaptionChacked")
                                        value:		taskModel.ScannedObjectCount
                                        captionFont:commonFontStyles.standardCommonTextFont
                                        valueFont:	commonFontStyles.standardCommonTextFont
                                        valueElide:	Text.ElideMiddle
                                    }
                                    Widgets.StaticLabel
                                    {
                                        caption:	taskModel.Localize(EnumHelper.getKey(taskModel, "Type") == "Vulnerability"
                                            ? "TaskManager_CaptionVulnerabilities" : "TaskManager_CaptionThreats")
                                        value:		taskModel.DetectedThreatCount > 0 ? taskModel.DetectedThreatCount : taskModel.Localize("TaskManager_Absend")
                                        captionFont:commonFontStyles.standardCommonTextFont
                                        valueFont:	commonFontStyles.standardCommonTextFont
                                        valueElide:	Text.ElideMiddle
                                    }
                                    Widgets.StaticLabel
                                    {
                                        caption:	taskModel.Localize("NeutralizedThreatCountName")
                                        value:		taskModel.NeutralizedThreatCount
                                        visible:  taskModel.DetectedThreatCount > 0
                                        captionFont:commonFontStyles.standardCommonTextFont
                                        valueFont:	commonFontStyles.standardCommonTextFont
                                        valueElide:	Text.ElideMiddle
                                    }
                                    Text
                                    {
                                        width:		parent.width
                                        textFormat:	Text.StyledText
                                        color: 		"gray";
                                        text:		taskModel.KsnStatistics
                                        font:       commonFontStyles.standardCommonTextFont
                                        visible:	dynamicFields.isStatisticsVisible()
                                        wrapMode: 	Text.Wrap
                                    }

                                    Widgets.Hyperlink
                                    {
                                        text: taskModel.Localize("TaskManager_CaptionDetails")
                                        visible:	dynamicFields.isStatisticsVisible();
                                        onClicked: taskModel.ShowFileAdvisorDialog();
                                    }

                                    Item
                                    {
                                        id:			onCompleteAction
                                        width:		parent.width
                                        height:		captionText.height
                                        visible:	EnumHelper.getKey(taskModel, "Type") == "Full" && taskModel.IsRunning;

                                        Text
                                        {
                                            id:		captionText
                                            text:	taskModel.Localize("TaskManager_CaptionOnComplete")
                                            color:	"black";

                                            font:commonFontStyles.standardCommonTextFont
                                            verticalAlignment: Text.AlignVCenter
                                        }

                                        Widgets.EnumCombo
                                        {
                                            id:					enumCombo
                                            anchors.left:		captionText.right
                                            anchors.leftMargin:	4
                                            valueFont:			commonFontStyles.standardCommonTextFont
                                            listFont:			commonFontStyles.standardListBoxFont

                                            isBindingEnabled:		EnumHelper.getKey(taskModel, "Type") == "Full" && taskModel.IsRunning;

                                            enumPropertyHolder: taskModel
                                            enumPropertyTitle: "ActionOnTaskCompleted"
                                            enumPropertyObject: taskModel.ActionOnTaskCompleted
                                                    onEnumPropertyChanged:
                                                    {
                                                        if(EnumHelper.getKey(taskModel, "Type") == "Full")
                                                            taskModel.ActionOnTaskCompleted = enumProperty;
                                                    }
                                        }
                                    }
                                }
                                Column
                                {
                                    id: 				descriptionForFailedScan
                                    width:				parent.width
                                    spacing:			12
                                    visible:			taskModel.IsFailed

                                    Widgets.StaticLabel
                                    {
                                        valueColor:	"blue"
                                        caption:	taskModel.Localize("SinceTaskFailDescription")
                                        value:		taskModel.DurationSinceLastStop
                                        captionFont:commonFontStyles.standardCommonTextFont
                                        valueFont:	commonFontStyles.standardCommonTextFont
                                        valueElide:	Text.ElideMiddle
                                    }

                                    Text
                                    {
                                        text: taskModel.LastError
                                        font: commonFontStyles.standardCommonTextFont
                                        wrapMode: 	Text.Wrap
                                    }
                                }
                            }

                            Item
                            {
                                id: 					progress
                                objectName: "progress"
                                width: 					parent.width
                                height:					stopTaskButton.height
                                anchors.top:			dynamicFields.bottom;
                                anchors.topMargin:		8;
                                visible:				taskModel.IsRunning && !taskModel.IsStopping

                                Widgets.TaskProgressBar
                                {
                                    id: 					progressBar;
                                    anchors.left:			parent.left
                                    anchors.right:			stopTaskButton.left;
                                    anchors.rightMargin:	8
                                    percent: progress.visible ? taskModel.CompletionPercent : 0;
                                }
                                Widgets.Button
                                {
                                    id:						stopTaskButton
                                    objectName: "stopTaskButton"
                                    anchors.right:			parent.right;
                                    anchors.verticalCenter:progressBar.verticalCenter;
                                    enabled: taskModel.CanStop;
                                    visible: taskModel.CanStop;

                                    iconImage:"../images/task_manager/stop_normal.png"
                                    iconHoverImage:"../images/task_manager/stop_hover.png"
                                    iconPressedImage:"../images/task_manager/stop_pressed.png"
                                    onClicked: setBackPosition();
                                }
                            }
                            // Vulnerability specific
                            Item
                            {
                                id:					vulnerabilitiesList
                                objectName: "vulnerabilitiesList"
                                width: 				150
                                height:				30;
                                anchors.top:		dynamicFields.bottom;
                                anchors.topMargin:	15

                                visible: EnumHelper.getKey(taskModel, "Type") == "Vulnerability" && !taskModel.IsRunning && !taskModel.IsFailed
                                Widgets.GrayButton
                                {
									objectName: "TaskManager_CaptionVulnerabilitieList"
                                    text:			taskModel.Localize("TaskManager_CaptionVulnerabilitieList")
                                    onClicked: taskModel.ShowVulnerabilityList.Invoke();
                                }
                            }
                        }
                    }
                }
                back: Item
                {
                    id:		askPanel
                    objectName: "askPanel"
                    width:	frontView.width
                    height:	frontView.height

                    Widgets.EmbeddedMessageBox
                    {
                        id: stopMessageBox
                        objectName: "stopMessageBox"

                        width:			parent.width - 60;
                        height:			parent.height;
                        anchors.centerIn: parent

                        text:				taskModel.Localize("TaskManager_ConfirmationMessage" + EnumHelper.getKey(taskModel, "Type"))
                        font:				commonFontStyles.standardBoldSubHeadingFont
                        leftButtonText:		taskModel.Localize("TaskManager_Confirm")
                        rightButtonText:	taskModel.Localize("TaskManager_Decline")
                        buttonsWidth:		100
                        buttonsHeight:		30

                        onLeftClicked:
                        {
                            setFrontPosition();
                            taskModel.Stop();
                        }
                        onRightClicked:
                        {
                            setFrontPosition();
                        }
                    }
                }
            }
        }
    }
}
