import Qt 4.7
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets

Item
{
	id: view
	objectName: "toolList"
	height: 130
	Widgets.DPIScaler { changeHeight: true }

	// public
	signal activate(string panelName)
	property bool canLeft:  !firstScreen
	property bool canRight: !lastScreen

	function doLeft()
	{
		if (canLeft)
			--currentScreen
	}

	function doRight()
	{
		if (canRight)
			++currentScreen
	}

	// private
	property int featuresPerRow: 5
	property int cellWidth: (width / featuresPerRow) + 1
	property int cellHeight: 68
	property int currentScreen: 0
	property int screenCount: Math.ceil(listView.count / featuresPerRow)
	property bool firstScreen: currentScreen == 0
	property bool lastScreen: currentScreen + 1 == screenCount

	ListView
	{
		id: listView
		objectName: "toolListView"
		property int focusIndex: 0
		property int tabOrder: 303
		clip: true
		anchors.horizontalCenter: parent.horizontalCenter
		anchors.verticalCenter:   parent.verticalCenter
		anchors.verticalCenterOffset : -10
		delegate: ToolListItem
		{
			width: view.cellWidth;
			height: view.cellHeight + 68;
			Widgets.DPIScaler{changeHeight:true}
			onActivate: view.activate(panelName)
			onRightPressed:
			{
				// proof-of-concept handling tool list elements focus
				//++listView.focusIndex
				//if (listView.focusIndex % 4 == 0)
				//	++view.currentScreen
			}
		}
		height: (parent.height * 0.85) + 10
		width: parent.width
		model: MainWindow.toolsList
		orientation: ListView.Horizontal
		interactive: false
		preferredHighlightBegin: 0
		preferredHighlightEnd: view.cellWidth
		highlightRangeMode: ListView.ApplyRange
		function calculateCurrentIndex()
		{
			var index = view.currentScreen * view.featuresPerRow;
			var extraItems = index + view.featuresPerRow - listView.count;
			return (view.currentScreen && view.lastScreen) ? (index - extraItems) : index;
		}
		currentIndex: calculateCurrentIndex()
		highlightMoveSpeed: 1200
	}

	Row
	{
		anchors.bottom: listView.bottom
		anchors.bottomMargin: 5
		anchors.horizontalCenter: listView.horizontalCenter
		objectName: "row"
		Repeater
		{
			model: view.screenCount
			objectName: "repeater"
			Widgets.Button
			{
				iconImage: "image://preload/common/images/main_window/featurebox/center_switches_" + (view.currentScreen == index ? "selected" : "normal") + ".png"
				iconHoverImage: "../images/main_window/featurebox/center_switches_hover.png"
				onClicked: view.currentScreen = index;
			}
		}
	}

	MouseWheelArea
	{
		anchors.fill: parent
		onVerticalWheel: wheel(delta)
		onHorizontalWheel: wheel(delta)
		function wheel(delta)
		{
			if (canLeft && delta > 0)
				doLeft()
			else if (canRight && delta < 0)
				doRight()
		}
	}
}

